@@ -2,7 +2,7 @@ package Date::Holidays::TW;
 use strict;
 use utf8;
 
-our $VERSION = v0.6.0;
+our $VERSION = v0.7.0;
 
 use Exporter 'import';
 our @EXPORT_OK = qw(is_tw_holiday tw_holidays);
@@ -1580,6 +1580,7 @@ my %CAL = (
         "0921" => "星期六、星期日",
         "0927" => "星期六、星期日",
         "0928" => "星期六、星期日",
+        "0929" => "補假",
         "1004" => "星期六、星期日",
         "1005" => "星期六、星期日",
         "1006" => "中秋節",
@@ -1588,7 +1589,8 @@ my %CAL = (
         "1012" => "星期六、星期日",
         "1018" => "星期六、星期日",
         "1019" => "星期六、星期日",
-        "1025" => "星期六、星期日",
+        "1024" => "補假",
+        "1025" => "臺灣光復暨金門古寧頭大捷紀念日",
         "1026" => "星期六、星期日",
         "1101" => "星期六、星期日",
         "1102" => "星期六、星期日",
@@ -1606,6 +1608,7 @@ my %CAL = (
         "1214" => "星期六、星期日",
         "1220" => "星期六、星期日",
         "1221" => "星期六、星期日",
+        "1225" => "行憲紀念日",
         "1227" => "星期六、星期日",
         "1228" => "星期六、星期日",
     },
